*******
Support
*******

Any issues or bugs with this package can be reported using the bug tracker:
https://bitbucket.org/libateq/tryton-modules/issues

If you are looking for commercial support, custom enhancements, or would just
like to support the maintenance and upkeep of this module, then please don't
hesitate to get in touch:

* Email: Support <support@libateq.uk>
* Website: https://libateq.uk/support/
